@@ -1,7 +1,6 @@
 from abc import ABC, abstractmethod
 from typing import List,Tuple,Set,Dict
-from lxml.etree import iselement
-from goyabucli.utils import headers
+from .utils import headers
 
 class VideoUrl():
     def __init__(self, url:str, quality:str, lang:str, source:str, scrapers:List['Scraper']=[], ready=False):
@@ -190,11 +189,3 @@ class Scraper(ABC):
     def episodes(self, animePageUrl) -> List[Episode]:
         raise NotImplementedError(f"episodes not implemented for '{self.name}'")
 
-    def is_element_valid(self, element):
-        if isinstance(element, list) and iselement(element[0]) and element[0]:
-            return True
-        return False
-
-
-
-
