@@ -1,15 +1,15 @@
 from typing import List, Dict
 from .scraper import Scraper,Anime,bindScrapers
-from .scrapers.goyabuNew import Goyabu
+from .scrapers.goyabu import Goyabu
 from .scrapers.animefire import AnimeFire
-from .scrapers.anime123 import Anime123
+from .scrapers.gogoanime import Gogoanime
 
-SCRAPERS:List[Scraper] = [AnimeFire(), Goyabu()]
-# SCRAPERS:List[Scraper] = [Anime123()]
+SCRAPERS:List[Scraper] = [AnimeFire(), Goyabu(), Gogoanime()]
 
 class ScraperManager():
     def __init__(self):
         self.scrapers = SCRAPERS
+
         self.animes:Dict[str,Anime] = {
             # 'id1' : Anime('title', 'anime1')
         }
@@ -20,11 +20,13 @@ class ScraperManager():
         if preferedScrapers:
             scrapers = [scraper for scraper in self.scrapers if scraper.name in preferedScrapers]
 
+        new_animes = []
         for scraper in scrapers:
             for anime in scraper.search(query):
+                new_animes.append(anime)
                 self._addAnime(anime)
 
-        return list(self.animes.values())
+        return new_animes
 
     def searchLocal(self, query:str) -> List[Anime]:
         return [Anime('title', 'anime1')]
